@@ -119,7 +119,7 @@ def _get_ssh_vendor() -> "SSHVendor":
         return SubprocessSSHVendor()
 
     if sys.platform == "win32" and os.environ.get("MSYSTEM") and shutil.which("ssh"):
-        # see https://github.com/iterative/dvc/issues/7702
+        # see https://github.com/treeverse/dvc/issues/7702
         logger.debug(
             "dulwich: native win32 Python inside MSYS2/git-bash, using MSYS2 OpenSSH"
         )
@@ -369,13 +369,18 @@ class DulwichBackend(BaseGitBackend):  # pylint:disable=abstract-method
                     yield rel
 
     def commit(self, msg: str, no_verify: bool = False):
+        from dulwich import __version__ as dulwich_version
         from dulwich.errors import CommitError
         from dulwich.porcelain import Error, TimezoneFormatError, commit
         from dulwich.repo import InvalidUserIdentity
 
+        commit_kwargs: dict[str, Any] = {}
+        if dulwich_version >= (0, 24, 3):
+            commit_kwargs["sign"] = False
+
         with reraise((Error, CommitError), SCMError("Git commit failed")):
             try:
-                commit(self.repo, message=msg, no_verify=no_verify)
+                commit(self.repo, message=msg, no_verify=no_verify, **commit_kwargs)
             except InvalidUserIdentity as exc:
                 raise SCMError("Git username and email must be configured") from exc
             except TimezoneFormatError as exc:
@@ -601,14 +606,13 @@ class DulwichBackend(BaseGitBackend):  # pylint:disable=abstract-method
             raise InvalidRemote(url) from exc
 
         try:
+            refs = client.get_refs(path.encode()).refs
+
             if base:
-                yield from (
-                    os.fsdecode(ref)
-                    for ref in client.get_refs(path.encode())
-                    if ref.startswith(os.fsencode(base))
-                )
+                base_b = os.fsencode(base)
+                yield from (os.fsdecode(ref) for ref in refs if ref.startswith(base_b))
             else:
-                yield from (os.fsdecode(ref) for ref in client.get_refs(path.encode()))
+                yield from (os.fsdecode(ref) for ref in refs)
         except NotGitRepository as exc:
             raise InvalidRemote(url) from exc
         except HTTPUnauthorized as exc:
